@@ -15,20 +15,14 @@ import aws_cdk.aws_elasticloadbalancingv2._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_wafv2._jsii
 import aws_cdk.core._jsii
-import aws_solutions_constructs.aws_apigateway_dynamodb._jsii
-import aws_solutions_constructs.aws_apigateway_iot._jsii
-import aws_solutions_constructs.aws_apigateway_kinesisstreams._jsii
-import aws_solutions_constructs.aws_apigateway_lambda._jsii
-import aws_solutions_constructs.aws_apigateway_sagemakerendpoint._jsii
-import aws_solutions_constructs.aws_apigateway_sqs._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-wafwebacl-apigateway",
-    "1.146.0",
+    "1.147.0",
     __name__[0:-6],
-    "aws-wafwebacl-apigateway@1.146.0.jsii.tgz",
+    "aws-wafwebacl-apigateway@1.147.0.jsii.tgz",
 )
 
 __all__ = [
